// PoV-Ray 3.7 Reference axes.
//
// derived from the original code of:
// 		Friedrich A. Lohmueller, 2005/2009/2011/2011
// author: 	Alessandro Accattini,    2014/2016
// email:	bit.trapper@gmail.com
// homepage:	http://escogito.altervista.org
//
//------------------------------------------------------------------------

#include "colors.inc"
global_settings{ assumed_gamma 1.0 } 

//------------------------------------------------------------------------
//------------------------- Axes textures --------------------------------

#declare Axis_Dark_Texture= texture
			    {
                              pigment{color rgb<1,0.35,0>}
                              finish {ambient 0.15 diffuse 0.85 phong 1}
                            }
#declare Axis_Light_Texture=texture 
			    {
                              pigment{color rgb<1,1,1>}
                              finish {ambient 0.15 diffuse 0.85 phong 1}
                            }

//------------------------------------------------------------------------
//------------------------------ the Axes --------------------------------

#macro Axis_(AxisLen,AxisUnit)
  union{
    cylinder
    { 
      <0,-AxisLen-1,0>,<0,AxisLen,0>,0.05
      texture
      {
        checker texture{ Axis_Dark_Texture }  texture{ Axis_Light_Texture }
        translate<0.1,0,0.1>
	scale AxisUnit
      }
    }
    cone
    {
      <0,AxisLen,0>,0.2,<0,AxisLen+0.7,0>,0
      texture{Axis_Dark_Texture}
    }
  }
#end

// ground -----------------------------------------------------------------
//---------------------------------<<< settings of squered plane dimensions
#declare RasterScale = 1.0;
#declare RasterHalfLine  = 0.045;
#declare RasterHalfLineZ = 0.045;
//-------------------------------------------------------------------------
#macro Raster(RScale, HLine)
  pigment
  { 
    gradient x scale RScale
    color_map
    {
      [0.000   color rgbt<1,1,1,1>*0.6]
      [0+HLine color rgbt<1,1,1,1>*0.6]
      [0+HLine color rgbt<1,1,1,1>]
      [1-HLine color rgbt<1,1,1,1>]
      [1-HLine color rgbt<1,1,1,1>*0.6]
      [1.000   color rgbt<1,1,1,1>*0.6]
    } 
  }
  finish 
  { 
    ambient 0.15 
    diffuse 0.85
  }
#end
//-------------------------------------------------------------------------


#macro AxisXYZ(AxisLenX,AxisLenY,AxisLenZ,AxisUnitX,AxisUnitY,AxisUnitZ,
	       XYplane,XZplane,YZplane)
  union
  {
    #if (AxisLenX != 0)				// x-Axis
      object 
      { 
	Axis_(AxisLenX, AxisUnitX)   
	rotate< 0,0,-90>
      }
      text   
      { 
	ttf "crystal.ttf",  "x",  0.15,  0  
	texture{Axis_Dark_Texture}
	scale 0.5 
	translate <AxisLenX+0.05,0.4,-0.10>
      }
    #end
    
    #if (AxisLenY != 0)				// y-Axis
      object 
      { 
	Axis_(AxisLenY, AxisUnitY)   
	rotate< 0,0,  0>
      }
      text
      { 
	ttf "crystal.ttf",  "y",  0.15,  0  
	texture{Axis_Dark_Texture}
	scale 0.5 
	translate <-0.55,AxisLenY+0.20,-0.10>
      }
    #end
    
    #if (AxisLenZ != 0)				// z-Axis
      object 
      { 
        Axis_(AxisLenZ, AxisUnitZ)   
	rotate<90,0,  0>
      }
      text   
      { 
        ttf "crystal.ttf",  "z",  0.15,  0  
	texture{Axis_Dark_Texture}
	scale 0.5 
	translate <-0.55,0.1,AxisLenZ+0.10>
      }
    #end

    #if (XYplane != 0)				// xy-Plane
      plane 
      { <0,1,0>, 0		// plane with layered textures
	texture 
	{ 
	  pigment{ color rgbt<1,1,1,0.7>*1.1 }
	  finish 
	  {
	    ambient 0.45 
	    diffuse 0.85
	  }
	}
	texture { Raster(AxisUnitX,RasterHalfLine ) rotate <0, 0,0> }
	texture { Raster(AxisUnitY,RasterHalfLine ) rotate <0,90,0> }
	rotate <90,0,0>
	no_shadow
      }
    #end
    
    #if (XZplane != 0)				// xz-Plane
      plane 
      { <0,1,0>, 0		// plane with layered textures
	texture 
	{ 
	  pigment{ color rgbt<1,1,1,0.7>*1.1 }
	  finish 
	  {
	    ambient 0.45 
	    diffuse 0.85
	  }
	}
	texture { Raster(AxisUnitX,RasterHalfLine ) rotate<0, 0,0> }
	texture { Raster(AxisUnitZ,RasterHalfLine ) rotate<0,90,0> }
	rotate <0,0,0>
	no_shadow
      }
    #end
    
    #if (YZplane != 0)				// yz-Plane
      plane 
      { <1,0,0>, 0		// plane with layered textures
	texture 
	{ 
	  pigment{ color rgbt<1,1,1,0.7>*1.1 }
	  finish 
	  {
	    ambient 0.45 
	    diffuse 0.85
	  }
	}
	texture { Raster(AxisUnitY,RasterHalfLine ) rotate<0, 0,0> }
	texture { Raster(AxisUnitZ,RasterHalfLine ) rotate<0,90,0> }
	rotate <0,0,90>
	no_shadow
      }
    #end
  }
#end




